@@ -78,7 +78,7 @@ static void notimplemented(char *s)
 #define ASSIGNVP8(x, y, vp) vp = VBUF + (y) * BYTEWIDTH + (x);
 #define ASSIGNVPOFFSET8(x, y, vp) vp = (y) * BYTEWIDTH + (x);
 
-void driver8_setpixel(int x, int y, int c)
+void __svgalib_driver8_setpixel(int x, int y, int c)
 {
 #ifdef __alpha__
     vga_setcolor(c);
@@ -90,7 +90,7 @@ void driver8_setpixel(int x, int y, int c)
 #endif
 }
 
-void driver8p_setpixel(int x, int y, int c)
+void __svgalib_driver8p_setpixel(int x, int y, int c)
 {
     int vp;
     ASSIGNVPOFFSET8(x, y, vp);
@@ -98,14 +98,14 @@ void driver8p_setpixel(int x, int y, int c)
     *(VBUF + (vp & 0xffff)) = c;
 }
 
-int driver8_getpixel(int x, int y)
+int __svgalib_driver8_getpixel(int x, int y)
 {
     char *vp;
     ASSIGNVP8(x, y, vp);
     return *vp;
 }
 
-int driver8p_getpixel(int x, int y)
+int __svgalib_driver8p_getpixel(int x, int y)
 {
     int vp;
     ASSIGNVPOFFSET8(x, y, vp);
@@ -113,14 +113,14 @@ int driver8p_getpixel(int x, int y)
     return *(VBUF + (vp & 0xffff));
 }
 
-void driver8_hline(int x1, int y, int x2, int c)
+void __svgalib_driver8_hline(int x1, int y, int x2, int c)
 {
     char *vp;
     ASSIGNVP8(x1, y, vp);
     __memset(vp, c, x2 - x1 + 1);
 }
 
-void driver8p_hline(int x1, int y, int x2, int c)
+void __svgalib_driver8p_hline(int x1, int y, int x2, int c)
 {
     int vp;
     char *rvp;
@@ -138,7 +138,7 @@ void driver8p_hline(int x1, int y, int x2, int c)
     }
 }
 
-void driver8_fillbox(int x, int y, int w, int h, int c)
+void __svgalib_driver8_fillbox(int x, int y, int w, int h, int c)
 {
     char *vp;
     int i;
@@ -149,20 +149,17 @@ void driver8_fillbox(int x, int y, int w, int h, int c)
     }
 }
 
-void driver8a_fillbox(int x, int y, int w, int h, int c)
+void __svgalib_driver8a_fillbox(int x, int y, int w, int h, int c)
 {
     if (w * h < 128)
-	if (MODETYPE == CONTEXT_LINEAR)
-	    driver8_fillbox(x, y, w, h, c);
-	else
-	    driver8p_fillbox(x, y, w, h, c);
+	(*__svgalib_nonaccel_fillbox)(x, y, w, h, c);
     else {
 	vga_accel(ACCEL_SETFGCOLOR, c);
 	vga_accel(ACCEL_FILLBOX, x, y, w, h);
     }
 }
 
-void driver8p_fillbox(int x, int y, int w, int h, int c)
+void __svgalib_driver8p_fillbox(int x, int y, int w, int h, int c)
 {
     int vp;
     int page;
@@ -190,7 +187,7 @@ void driver8p_fillbox(int x, int y, int w, int h, int c)
     }
 }
 
-void driver8_putbox(int x, int y, int w, int h, void *b, int bw)
+void __svgalib_driver8_putbox(int x, int y, int w, int h, void *b, int bw)
 {
     char *vp;			/* screen pointer */
     char *bp;			/* bitmap pointer */
@@ -204,7 +201,7 @@ void driver8_putbox(int x, int y, int w, int h, void *b, int bw)
     }
 }
 
-void driver8p_putbox(int x, int y, int w, int h, void *b, int bw)
+void __svgalib_driver8p_putbox(int x, int y, int w, int h, void *b, int bw)
 {
 /* extra argument width of source bitmap, so that putboxpart can use this */
     int vp;
@@ -237,7 +234,7 @@ void driver8p_putbox(int x, int y, int w, int h, void *b, int bw)
     }
 }
 
-void driver8_getbox(int x, int y, int w, int h, void *b, int bw)
+void __svgalib_driver8_getbox(int x, int y, int w, int h, void *b, int bw)
 {
     char *vp;			/* screen pointer */
     char *bp;			/* bitmap pointer */
@@ -251,7 +248,7 @@ void driver8_getbox(int x, int y, int w, int h, void *b, int bw)
     }
 }
 
-void driver8p_getbox(int x, int y, int w, int h, void *b, int bw)
+void __svgalib_driver8p_getbox(int x, int y, int w, int h, void *b, int bw)
 {
     int vp;
     int page;
@@ -283,7 +280,7 @@ void driver8p_getbox(int x, int y, int w, int h, void *b, int bw)
     }
 }
 
-void driver8_putboxmask(int x, int y, int w, int h, void *b)
+void __svgalib_driver8_putboxmask(int x, int y, int w, int h, void *b)
 {
     uchar *bp = b;
     uchar *vp;
@@ -318,31 +315,31 @@ void driver8_putboxmask(int x, int y, int w, int h, void *b)
     }
 }
 
-void driver8_putboxpart(int x, int y, int w, int h, int ow, int oh,
+void __svgalib_driver8_putboxpart(int x, int y, int w, int h, int ow, int oh,
 			void *b, int xo, int yo)
 {
-    driver8_putbox(x, y, w, h, b + yo * ow + xo, ow);	/* inlined */
+    __svgalib_driver8_putbox(x, y, w, h, b + yo * ow + xo, ow);	/* inlined */
 }
 
-void driver8p_putboxpart(int x, int y, int w, int h, int ow, int oh,
+void __svgalib_driver8p_putboxpart(int x, int y, int w, int h, int ow, int oh,
 			 void *b, int xo, int yo)
 {
-    driver8p_putbox(x, y, w, h, b + yo * ow + xo, ow);	/* inlined */
+    __svgalib_driver8p_putbox(x, y, w, h, b + yo * ow + xo, ow);	/* inlined */
 }
 
-void driver8_getboxpart(int x, int y, int w, int h, int ow, int oh,
+void __svgalib_driver8_getboxpart(int x, int y, int w, int h, int ow, int oh,
 			void *b, int xo, int yo)
 {
-    driver8_getbox(x, y, w, h, b + yo * ow + xo, ow);
+    __svgalib_driver8_getbox(x, y, w, h, b + yo * ow + xo, ow);
 }
 
-void driver8p_getboxpart(int x, int y, int w, int h, int ow, int oh,
+void __svgalib_driver8p_getboxpart(int x, int y, int w, int h, int ow, int oh,
 			 void *b, int xo, int yo)
 {
-    driver8p_getbox(x, y, w, h, b + yo * ow + xo, ow);
+    __svgalib_driver8p_getbox(x, y, w, h, b + yo * ow + xo, ow);
 }
 
-void driver8_copybox(int x1, int y1, int w, int h, int x2, int y2)
+void __svgalib_driver8_copybox(int x1, int y1, int w, int h, int x2, int y2)
 {
     char *svp, *dvp;
     /* I hope this works now. */
@@ -384,7 +381,7 @@ void driver8_copybox(int x1, int y1, int w, int h, int x2, int y2)
     }
 }
 
-void driver8a_copybox(int x1, int y1, int w, int h, int x2, int y2)
+void __svgalib_driver8a_copybox(int x1, int y1, int w, int h, int x2, int y2)
 {
     vga_accel(ACCEL_SCREENCOPY, x1, y1, x2, y2, w, h);
 }
@@ -396,14 +393,14 @@ void driver8a_copybox(int x1, int y1, int w, int h, int x2, int y2)
 #define ASSIGNVP16(x, y, vp) vp = VBUF + (y) * BYTEWIDTH + (x) * 2;
 #define ASSIGNVPOFFSET16(x, y, vp) vp = (y) * BYTEWIDTH + (x) * 2;
 
-void driver16_setpixel(int x, int y, int c)
+void __svgalib_driver16_setpixel(int x, int y, int c)
 {
     char *vp;
     ASSIGNVP16(x, y, vp);
     *(unsigned short *) vp = c;
 }
 
-void driver16p_setpixel(int x, int y, int c)
+void __svgalib_driver16p_setpixel(int x, int y, int c)
 {
     int vp;
     ASSIGNVPOFFSET16(x, y, vp);
@@ -411,14 +408,14 @@ void driver16p_setpixel(int x, int y, int c)
     *(unsigned short *) (VBUF + (vp & 0xffff)) = c;
 }
 
-int driver16_getpixel(int x, int y)
+int __svgalib_driver16_getpixel(int x, int y)
 {
     char *vp;
     ASSIGNVP16(x, y, vp);
     return *(unsigned short *) vp;
 }
 
-int driver16p_getpixel(int x, int y)
+int __svgalib_driver16p_getpixel(int x, int y)
 {
     int vp;
     ASSIGNVPOFFSET16(x, y, vp);
@@ -426,14 +423,14 @@ int driver16p_getpixel(int x, int y)
     return *(unsigned short *) (VBUF + (vp & 0xffff));
 }
 
-void driver16_hline(int x1, int y, int x2, int c)
+void __svgalib_driver16_hline(int x1, int y, int x2, int c)
 {
     char *vp;
     ASSIGNVP16(x1, y, vp);
     __memset2(vp, c, x2 - x1 + 1);
 }
 
-void driver16p_hline(int x1, int y, int x2, int c)
+void __svgalib_driver16p_hline(int x1, int y, int x2, int c)
 {
     int vp;
     char *rvp;
@@ -451,7 +448,7 @@ void driver16p_hline(int x1, int y, int x2, int c)
     }
 }
 
-void driver16_fillbox(int x, int y, int w, int h, int c)
+void __svgalib_driver16_fillbox(int x, int y, int w, int h, int c)
 {
     char *vp;
     int i;
@@ -462,7 +459,7 @@ void driver16_fillbox(int x, int y, int w, int h, int c)
     }
 }
 
-void driver16p_fillbox(int x, int y, int w, int h, int c)
+void __svgalib_driver16p_fillbox(int x, int y, int w, int h, int c)
 {
     int vp;
     int page;
@@ -490,7 +487,7 @@ void driver16p_fillbox(int x, int y, int w, int h, int c)
     }
 }
 
-void driver16_putbox(int x, int y, int w, int h, void *b, int bw)
+void __svgalib_driver16_putbox(int x, int y, int w, int h, void *b, int bw)
 {
     char *vp;			/* screen pointer */
     char *bp;			/* bitmap pointer */
@@ -504,12 +501,12 @@ void driver16_putbox(int x, int y, int w, int h, void *b, int bw)
     }
 }
 
-void driver16p_putbox(int x, int y, int w, int h, void *b, int bw)
+void __svgalib_driver16p_putbox(int x, int y, int w, int h, void *b, int bw)
 {
-    driver8p_putbox(x * 2, y, w * 2, h, b, bw * 2);
+    __svgalib_driver8p_putbox(x * 2, y, w * 2, h, b, bw * 2);
 }
 
-void driver16_getbox(int x, int y, int w, int h, void *b, int bw)
+void __svgalib_driver16_getbox(int x, int y, int w, int h, void *b, int bw)
 {
     char *vp;			/* screen pointer */
     char *bp;			/* bitmap pointer */
@@ -523,12 +520,12 @@ void driver16_getbox(int x, int y, int w, int h, void *b, int bw)
     }
 }
 
-INLINE void driver16p_getbox(int x, int y, int w, int h, void *b, int bw)
+INLINE void __svgalib_driver16p_getbox(int x, int y, int w, int h, void *b, int bw)
 {
-    driver8p_getbox(x * 2, y, w * 2, h, b, bw * 2);
+    __svgalib_driver8p_getbox(x * 2, y, w * 2, h, b, bw * 2);
 }
 
-void driver16_putboxmask(int x, int y, int w, int h, void *b)
+void __svgalib_driver16_putboxmask(int x, int y, int w, int h, void *b)
 {
     uchar *bp = b;
     uchar *vp;
@@ -563,37 +560,37 @@ void driver16_putboxmask(int x, int y, int w, int h, void *b)
     }
 }
 
-INLINE void driver16_putboxpart(int x, int y, int w, int h, int ow, int oh,
+INLINE void __svgalib_driver16_putboxpart(int x, int y, int w, int h, int ow, int oh,
 				void *b, int xo, int yo)
 {
-    driver8_putbox(x * 2, y, w * 2, h, b + yo * ow * 2 + xo * 2, ow * 2);
+    __svgalib_driver8_putbox(x * 2, y, w * 2, h, b + yo * ow * 2 + xo * 2, ow * 2);
     /* inlined */
 }
 
-INLINE void driver16p_putboxpart(int x, int y, int w, int h, int ow, int oh,
+INLINE void __svgalib_driver16p_putboxpart(int x, int y, int w, int h, int ow, int oh,
 				 void *b, int xo, int yo)
 {
-    driver8p_putbox(x * 2, y, w * 2, h, b + yo * ow * 2 + xo * 2, ow * 2);
+    __svgalib_driver8p_putbox(x * 2, y, w * 2, h, b + yo * ow * 2 + xo * 2, ow * 2);
 }
 
-INLINE void driver16_getboxpart(int x, int y, int w, int h, int ow, int oh,
+INLINE void __svgalib_driver16_getboxpart(int x, int y, int w, int h, int ow, int oh,
 				void *b, int xo, int yo)
 {
-    driver16_getbox(x, y, w, h, b + yo * ow + xo, ow);
+    __svgalib_driver16_getbox(x, y, w, h, b + yo * ow + xo, ow);
 }
 
-INLINE void driver16p_getboxpart(int x, int y, int w, int h, int ow, int oh,
+INLINE void __svgalib_driver16p_getboxpart(int x, int y, int w, int h, int ow, int oh,
 				 void *b, int xo, int yo)
 {
-    driver16p_getbox(x, y, w, h, b + yo * ow + xo, ow);
+    __svgalib_driver16p_getbox(x, y, w, h, b + yo * ow + xo, ow);
 }
 
-INLINE void driver16_copybox(int x1, int y1, int w, int h, int x2, int y2)
+INLINE void __svgalib_driver16_copybox(int x1, int y1, int w, int h, int x2, int y2)
 {
-    driver8_copybox(x1 * 2, y1, w * 2, h, x2 * 2, y2);
+    __svgalib_driver8_copybox(x1 * 2, y1, w * 2, h, x2 * 2, y2);
 }
 
-void driver16a_copybox(int x1, int y1, int w, int h, int x2, int y2)
+void __svgalib_driver16a_copybox(int x1, int y1, int w, int h, int x2, int y2)
 {
     int svp, dvp;
     ASSIGNVPOFFSET16(x1, y1, svp);
@@ -610,7 +607,7 @@ void driver16a_copybox(int x1, int y1, int w, int h, int x2, int y2)
 #define RGBEQUAL(c) ((c & 0xff) == ((c >> 8) & 0xff) && \
 	(c & 0xff) == ((c >> 16) & 0xff))
 
-void driver24_setpixel(int x, int y, int c)
+void __svgalib_driver24_setpixel(int x, int y, int c)
 {
     char *vp;
     c = RGB2BGR(c);
@@ -619,7 +616,7 @@ void driver24_setpixel(int x, int y, int c)
     *(unsigned char *) (vp + 2) = c >> 16;
 }
 
-void driver24p_setpixel(int x, int y, int c)
+void __svgalib_driver24p_setpixel(int x, int y, int c)
 {
     int vp, vpo;
     char *vbuf;
@@ -644,14 +641,14 @@ void driver24p_setpixel(int x, int y, int c)
     }
 }
 
-int driver24_getpixel(int x, int y)
+int __svgalib_driver24_getpixel(int x, int y)
 {
     char *vp;
     ASSIGNVP24(x, y, vp);
     return RGB2BGR(*(unsigned short *) vp + (*(unsigned char *) (vp + 2) << 16));
 }
 
-int driver24p_getpixel(int x, int y)
+int __svgalib_driver24p_getpixel(int x, int y)
 {
     int vp, vpo;
     char *vbuf;
@@ -677,7 +674,7 @@ int driver24p_getpixel(int x, int y)
     }
 }
 
-void driver24_hline(int x1, int y, int x2, int c)
+void __svgalib_driver24_hline(int x1, int y, int x2, int c)
 {
     char *vp;
     c = RGB2BGR(c);
@@ -688,7 +685,7 @@ void driver24_hline(int x1, int y, int x2, int c)
 	__memset3(vp, c, x2 - x1 + 1);
 }
 
-void driver24p_hline(int x1, int y, int x2, int c)
+void __svgalib_driver24p_hline(int x1, int y, int x2, int c)
 {
     int vp;
     char *rvp;
@@ -724,7 +721,7 @@ void driver24p_hline(int x1, int y, int x2, int c)
     }
 }
 
-void driver24_fillbox(int x, int y, int w, int h, int c)
+void __svgalib_driver24_fillbox(int x, int y, int w, int h, int c)
 {
     char *vp;
     int i, j;
@@ -741,7 +738,7 @@ void driver24_fillbox(int x, int y, int w, int h, int c)
 	}
 }
 
-void driver24p_fillbox(int x, int y, int w, int h, int c)
+void __svgalib_driver24p_fillbox(int x, int y, int w, int h, int c)
 {
     int vp;
     int page;
@@ -806,7 +803,7 @@ void driver24p_fillbox(int x, int y, int w, int h, int c)
 	}
 }
 
-void driver24_putbox(int x, int y, int w, int h, void *b, int bw)
+void __svgalib_driver24_putbox(int x, int y, int w, int h, void *b, int bw)
 {
     char *vp;			/* screen pointer */
     char *bp;			/* bitmap pointer */
@@ -887,16 +884,16 @@ static void driver24_rev_putbox(int x, int y, int w, int h, void *b, int bw)
     }
 }
 
-INLINE void driver24p_putbox(int x, int y, int w, int h, void *b, int bw)
+INLINE void __svgalib_driver24p_putbox(int x, int y, int w, int h, void *b, int bw)
 {
     if (MODEFLAGS & MODEFLAG_24BPP_REVERSED) {
 	driver24_rev_putbox(x * 3, y, w * 3, h, b, bw * 3);
     } else {
-	driver8p_putbox(x * 3, y, w * 3, h, b, bw * 3);
+	__svgalib_driver8p_putbox(x * 3, y, w * 3, h, b, bw * 3);
     }
 }
 
-void driver24_putbox32(int x, int y, int w, int h, void *b, int bw)
+void __svgalib_driver24_putbox32(int x, int y, int w, int h, void *b, int bw)
 {
     char *vp;			/* screen pointer */
     char *bp;			/* bitmap pointer */
@@ -904,13 +901,13 @@ void driver24_putbox32(int x, int y, int w, int h, void *b, int bw)
     ASSIGNVP24(x, y, vp);
     bp = b;
     for (i = 0; i < h; i++) {
-	memcpy4to3(vp, bp, w);
+	__svgalib_memcpy4to3(vp, bp, w);
 	bp += bw * 4;
 	vp += BYTEWIDTH;
     }
 }
 
-void driver24_getbox(int x, int y, int w, int h, void *b, int bw)
+void __svgalib_driver24_getbox(int x, int y, int w, int h, void *b, int bw)
 {
     char *vp;			/* screen pointer */
     char *bp;			/* bitmap pointer */
@@ -991,16 +988,16 @@ static void driver24_rev_getbox(int x, int y, int w, int h, void *b, int bw)
     }
 }
 
-INLINE void driver24p_getbox(int x, int y, int w, int h, void *b, int bw)
+INLINE void __svgalib_driver24p_getbox(int x, int y, int w, int h, void *b, int bw)
 {
     if (MODEFLAGS & MODEFLAG_24BPP_REVERSED) {
 	driver24_rev_getbox(x * 3, y, w * 3, h, b, bw * 3);
     } else {
-	driver8p_getbox(x * 3, y, w * 3, h, b, bw * 3);
+	__svgalib_driver8p_getbox(x * 3, y, w * 3, h, b, bw * 3);
     }
 }
 
-void driver24_putboxmask(int x, int y, int w, int h, void *b)
+void __svgalib_driver24_putboxmask(int x, int y, int w, int h, void *b)
 {
     uchar *bp = b;
     uchar *vp;
@@ -1045,48 +1042,48 @@ void driver24_putboxmask(int x, int y, int w, int h, void *b)
     }
 }
 
-INLINE void driver24_putboxpart(int x, int y, int w, int h, int ow, int oh,
+INLINE void __svgalib_driver24_putboxpart(int x, int y, int w, int h, int ow, int oh,
 				void *b, int xo, int yo)
 {
     /*
-     * Actually I think all this could be done by just calling driver24_putbox
+     * Actually I think all this could be done by just calling __svgalib_driver24_putbox
      * with correct args. But I'm too fearful. - Michael.
      */
     if (MODEFLAGS & MODEFLAG_24BPP_REVERSED) {
-	driver24_putbox(x, y, w, h, b + yo * ow + xo, ow);
+	__svgalib_driver24_putbox(x, y, w, h, b + yo * ow + xo, ow);
     } else {
-	driver8_putbox(x * 3, y, w * 3, h, b + yo * ow * 3 + xo * 3, ow * 3);
+	__svgalib_driver8_putbox(x * 3, y, w * 3, h, b + yo * ow * 3 + xo * 3, ow * 3);
     }
 }
 
-INLINE void driver24p_putboxpart(int x, int y, int w, int h, int ow, int oh,
+INLINE void __svgalib_driver24p_putboxpart(int x, int y, int w, int h, int ow, int oh,
 				 void *b, int xo, int yo)
 {
     if (MODEFLAGS & MODEFLAG_24BPP_REVERSED) {
 	driver24_rev_putbox(x * 3, y, w * 3, h, b + yo * ow * 3 + xo * 3, ow * 3);
     } else {
-	driver8p_putbox(x * 3, y, w * 3, h, b + yo * ow * 3 + xo * 3, ow * 3);
+	__svgalib_driver8p_putbox(x * 3, y, w * 3, h, b + yo * ow * 3 + xo * 3, ow * 3);
     }
 }
 
-INLINE void driver24_getboxpart(int x, int y, int w, int h, int ow, int oh,
+INLINE void __svgalib_driver24_getboxpart(int x, int y, int w, int h, int ow, int oh,
 				void *b, int xo, int yo)
 {
-    driver24_getbox(x, y, w, h, b + yo * ow + xo, ow);
+    __svgalib_driver24_getbox(x, y, w, h, b + yo * ow + xo, ow);
 }
 
-INLINE void driver24p_getboxpart(int x, int y, int w, int h, int ow, int oh,
+INLINE void __svgalib_driver24p_getboxpart(int x, int y, int w, int h, int ow, int oh,
 				 void *b, int xo, int yo)
 {
-    driver24p_getbox(x, y, w, h, b + yo * ow + xo, ow);
+    __svgalib_driver24p_getbox(x, y, w, h, b + yo * ow + xo, ow);
 }
 
-void driver24_copybox(int x1, int y1, int w, int h, int x2, int y2)
+void __svgalib_driver24_copybox(int x1, int y1, int w, int h, int x2, int y2)
 {
-    driver8_copybox(x1 * 3, y1, w * 3, h, x2 * 3, y2);
+    __svgalib_driver8_copybox(x1 * 3, y1, w * 3, h, x2 * 3, y2);
 }
 
-void driver24a_copybox(int x1, int y1, int w, int h, int x2, int y2)
+void __svgalib_driver24a_copybox(int x1, int y1, int w, int h, int x2, int y2)
 {
     int svp, dvp;
     ASSIGNVPOFFSET24(x1, y1, svp);
@@ -1101,14 +1098,14 @@ void driver24a_copybox(int x1, int y1, int w, int h, int x2, int y2)
 #define ASSIGNVP32(x, y, vp) vp = VBUF + (y) * BYTEWIDTH + (x) * 4;
 #define ASSIGNVPOFFSET32(x, y, vp) vp = (y) * BYTEWIDTH + (x) * 4;
 
-void driver32_setpixel(int x, int y, int c)
+void __svgalib_driver32_setpixel(int x, int y, int c)
 {
     char *vp;
     ASSIGNVP32(x, y, vp);
     *(unsigned *) vp = c;
 }
 
-void driver32p_setpixel(int x, int y, int c)
+void __svgalib_driver32p_setpixel(int x, int y, int c)
 {
     int vp;
     ASSIGNVPOFFSET32(x, y, vp);
@@ -1116,14 +1113,14 @@ void driver32p_setpixel(int x, int y, int c)
     *(unsigned *) (VBUF + (vp & 0xffff)) = c;
 }
 
-int driver32_getpixel(int x, int y)
+int __svgalib_driver32_getpixel(int x, int y)
 {
     char *vp;
     ASSIGNVP32(x, y, vp);
     return *(unsigned *) vp;
 }
 
-int driver32p_getpixel(int x, int y)
+int __svgalib_driver32p_getpixel(int x, int y)
 {
     int vp;
     ASSIGNVPOFFSET32(x, y, vp);
@@ -1131,14 +1128,14 @@ int driver32p_getpixel(int x, int y)
     return *(unsigned *) (VBUF + (vp & 0xffff));
 }
 
-void driver32_hline(int x1, int y, int x2, int c)
+void __svgalib_driver32_hline(int x1, int y, int x2, int c)
 {
     char *vp;
     ASSIGNVP32(x1, y, vp);
     __memsetlong(vp, c, x2 - x1 + 1);
 }
 
-void driver32p_hline(int x1, int y, int x2, int c)
+void __svgalib_driver32p_hline(int x1, int y, int x2, int c)
 {
     int vp;
     char *rvp;
@@ -1156,7 +1153,7 @@ void driver32p_hline(int x1, int y, int x2, int c)
     }
 }
 
-void driver32_fillbox(int x, int y, int w, int h, int c)
+void __svgalib_driver32_fillbox(int x, int y, int w, int h, int c)
 {
     char *vp;
     int i;
@@ -1167,7 +1164,7 @@ void driver32_fillbox(int x, int y, int w, int h, int c)
     }
 }
 
-void driver32p_fillbox(int x, int y, int w, int h, int c)
+void __svgalib_driver32p_fillbox(int x, int y, int w, int h, int c)
 {
     int vp;
     int page;
@@ -1195,27 +1192,27 @@ void driver32p_fillbox(int x, int y, int w, int h, int c)
     }
 }
 
-INLINE void driver32_putbox(int x, int y, int w, int h, void *b, int bw)
+INLINE void __svgalib_driver32_putbox(int x, int y, int w, int h, void *b, int bw)
 {
-    driver8_putbox(x * 4, y, w * 4, h, b, bw * 4);
+    __svgalib_driver8_putbox(x * 4, y, w * 4, h, b, bw * 4);
 }
 
-INLINE void driver32p_putbox(int x, int y, int w, int h, void *b, int bw)
+INLINE void __svgalib_driver32p_putbox(int x, int y, int w, int h, void *b, int bw)
 {
-    driver8p_putbox(x * 4, y, w * 4, h, b, bw * 4);
+    __svgalib_driver8p_putbox(x * 4, y, w * 4, h, b, bw * 4);
 }
 
-INLINE void driver32_getbox(int x, int y, int w, int h, void *b, int bw)
+INLINE void __svgalib_driver32_getbox(int x, int y, int w, int h, void *b, int bw)
 {
-    driver8_getbox(x * 4, y, w * 4, h, b, bw * 4);
+    __svgalib_driver8_getbox(x * 4, y, w * 4, h, b, bw * 4);
 }
 
-INLINE void driver32p_getbox(int x, int y, int w, int h, void *b, int bw)
+INLINE void __svgalib_driver32p_getbox(int x, int y, int w, int h, void *b, int bw)
 {
-    driver8p_getbox(x * 4, y, w * 4, h, b, bw * 4);
+    __svgalib_driver8p_getbox(x * 4, y, w * 4, h, b, bw * 4);
 }
 
-void driver32_putboxmask(int x, int y, int w, int h, void *b)
+void __svgalib_driver32_putboxmask(int x, int y, int w, int h, void *b)
 {
     uchar *bp = b;
     uchar *vp;
@@ -1250,47 +1247,47 @@ void driver32_putboxmask(int x, int y, int w, int h, void *b)
     }
 }
 
-INLINE void driver32_putboxpart(int x, int y, int w, int h, int ow, int oh,
+INLINE void __svgalib_driver32_putboxpart(int x, int y, int w, int h, int ow, int oh,
 				void *b, int xo, int yo)
 {
-    driver32_putbox(x, y, w, h, b + yo * ow + xo, ow);
+    __svgalib_driver32_putbox(x, y, w, h, b + yo * ow + xo, ow);
     /* inlined */
 }
 
-INLINE void driver32p_putboxpart(int x, int y, int w, int h, int ow, int oh,
+INLINE void __svgalib_driver32p_putboxpart(int x, int y, int w, int h, int ow, int oh,
 				 void *b, int xo, int yo)
 {
-    driver32p_putbox(x, y, w, h, b + yo * ow + xo, ow);
+    __svgalib_driver32p_putbox(x, y, w, h, b + yo * ow + xo, ow);
     /* inlined */
 }
 
-INLINE void driver32_getboxpart(int x, int y, int w, int h, int ow, int oh,
+INLINE void __svgalib_driver32_getboxpart(int x, int y, int w, int h, int ow, int oh,
 				void *b, int xo, int yo)
 {
-    driver32_getbox(x, y, w, h, b + yo * ow + xo, ow);
+    __svgalib_driver32_getbox(x, y, w, h, b + yo * ow + xo, ow);
 }
 
-INLINE void driver32p_getboxpart(int x, int y, int w, int h, int ow, int oh,
+INLINE void __svgalib_driver32p_getboxpart(int x, int y, int w, int h, int ow, int oh,
 				 void *b, int xo, int yo)
 {
-    driver32p_getbox(x, y, w, h, b + yo * ow + xo, ow);
+    __svgalib_driver32p_getbox(x, y, w, h, b + yo * ow + xo, ow);
 }
 
-INLINE void driver32_copybox(int x1, int y1, int w, int h, int x2, int y2)
+INLINE void __svgalib_driver32_copybox(int x1, int y1, int w, int h, int x2, int y2)
 {
-    driver8_copybox(x1 * 4, y1, w * 4, h, x2 * 4, y2);
+    __svgalib_driver8_copybox(x1 * 4, y1, w * 4, h, x2 * 4, y2);
 }
 
 
 
 /* Planar 256 color mode graphics primitives (only putbox) */
 
-void driverplanar256_nothing(void)
+void __svgalib_driverplanar256_nothing(void)
 {
     NOTIMPL("planar 256 color mode primitive");
 }
 
-void driverplanar256_putbox(int x, int y, int w, int h, void *b, int bw)
+void __svgalib_driverplanar256_putbox(int x, int y, int w, int h, void *b, int bw)
 {
     if ((w & 3) != 0 || (x & 3) != 0)
 	NOTIMPL("planar 256 color mode unaligned putbox");
@@ -1298,7 +1295,7 @@ void driverplanar256_putbox(int x, int y, int w, int h, void *b, int bw)
 			w, h);
 }
 
-void driverplanar16_nothing(void)
+void __svgalib_driverplanar16_nothing(void)
 {
     NOTIMPL("planar 16 color mode primitive");
 }
@@ -1306,7 +1303,7 @@ void driverplanar16_nothing(void)
 
 /* Memory primitives */
 
-int driver_setread(GraphicsContext * gc, int i, void **vp)
+int __svgalib_driver_setread(GraphicsContext * gc, int i, void **vp)
 {
     if (gc->modetype == CONTEXT_PAGED) {
 	vga_setpage(i >> 16);
@@ -1318,7 +1315,7 @@ int driver_setread(GraphicsContext * gc, int i, void **vp)
     }
 }
 
-int driver_setwrite(GraphicsContext * gc, int i, void **vp)
+int __svgalib_driver_setwrite(GraphicsContext * gc, int i, void **vp)
 {
     if (gc->modetype == CONTEXT_PAGED) {
 	vga_setpage(i >> 16);
@@ -1334,42 +1331,42 @@ int driver_setwrite(GraphicsContext * gc, int i, void **vp)
 
 /* Functions that are not yet implemented */
 
-void driver8p_putboxmask(int x, int y, int w, int h, void *b)
+void __svgalib_driver8p_putboxmask(int x, int y, int w, int h, void *b)
 {
     NOTIMPL("8-bit paged putboxmask");
 }
 
-void driver8p_copybox(int x1, int y1, int w, int h, int x2, int y2)
+void __svgalib_driver8p_copybox(int x1, int y1, int w, int h, int x2, int y2)
 {
     NOTIMPL("8-bit paged copybox (bitblt)");
 }
 
-void driver16p_putboxmask(int x, int y, int w, int h, void *b)
+void __svgalib_driver16p_putboxmask(int x, int y, int w, int h, void *b)
 {
     NOTIMPL("16-bit paged putboxmask");
 }
 
-void driver16p_copybox(int x1, int y1, int w, int h, int x2, int y2)
+void __svgalib_driver16p_copybox(int x1, int y1, int w, int h, int x2, int y2)
 {
     NOTIMPL("16-bit paged copybox");
 }
 
-void driver24p_putboxmask(int x, int y, int w, int h, void *b)
+void __svgalib_driver24p_putboxmask(int x, int y, int w, int h, void *b)
 {
     NOTIMPL("24-bit paged putboxmask");
 }
 
-void driver24p_copybox(int x1, int y1, int w, int h, int x2, int y2)
+void __svgalib_driver24p_copybox(int x1, int y1, int w, int h, int x2, int y2)
 {
     NOTIMPL("24-bit paged copybox");
 }
 
-void driver32p_putboxmask(int x, int y, int w, int h, void *b)
+void __svgalib_driver32p_putboxmask(int x, int y, int w, int h, void *b)
 {
     NOTIMPL("32-bit paged putboxmask");
 }
 
-void driver32p_copybox(int x1, int y1, int w, int h, int x2, int y2)
+void __svgalib_driver32p_copybox(int x1, int y1, int w, int h, int x2, int y2)
 {
     NOTIMPL("32-bit paged copybox");
 }
