@@ -902,9 +902,16 @@ void gl_copyboxtocontext(int x1, int y1, int w, int h, GraphicsContext * gc,
 #else
 	gl_setcontext(gc);
 #endif
+/*
+ * Note: Using save.bytewidth / BYTESPERPIXEL is probably not an optimal hack here.
+ * it would be better to transfer save.bytewidth to putbox as it is what is really
+ * used there. However, putbox is used all over interpreting the last entry as a
+ * pixel count, so we keep it this way to avoid problems if some other place not
+ * updated by accident.
+ */
 	putbox(x2, y2 + screenoffset / BYTEWIDTH, w, h, save.vbuf +
 	       y1 * save.bytewidth + x1 * BYTESPERPIXEL,
-	       save.bytewidth);
+	       save.bytewidth / BYTESPERPIXEL);
 	goto end;
     }
     buf = alloca(w * h * BYTESPERPIXEL);
@@ -947,9 +954,12 @@ void gl_copyboxfromcontext(GraphicsContext * gc, int x1, int y1, int w, int h,
     if ((gc->modetype == CONTEXT_LINEAR || gc->modetype == CONTEXT_VIRTUAL) &&
 	(BYTESPERPIXEL == gc->bytesperpixel) &&
 	!__clip && !gc->clip) {
+/*
+ * see above on  gc->bytewidth / BYTESPERPIXEL.
+ */
 	putbox(x2, y2 + screenoffset / BYTEWIDTH, w, h, gc->vbuf +
 	       y1 * gc->bytewidth + x1 * BYTESPERPIXEL,
-	       gc->bytewidth);
+	       gc->bytewidth / BYTESPERPIXEL);
 	return;
     }
     gl_getcontext(&save);
