@@ -231,8 +231,8 @@ static inline void *
 
 /* Functions defined in mem.S */
 
-extern __svgalib_memcpy4to3(void *dest, void *src, int n);
-extern __svgalib_memcpy32shift8(void *dest, void *src, int n);
+extern void __svgalib_memcpy4to3(void *dest, void *src, int n);
+extern void __svgalib_memcpy32shift8(void *dest, void *src, int n);
 
 /* Functions for which arguments must be passed in %ebx, %edx, and %ecx. */
 #if 0				/* Why declare 'em? Just confuses the compiler and can't be called from C
