@@ -106,6 +106,9 @@ return apm_is_linear;
 
 static void apm_getmodeinfo(int mode, vga_modeinfo *modeinfo)
 {
+
+    if(modeinfo->colors==16)return;
+
 	modeinfo->maxpixels = apm_memory*1024/modeinfo->bytesperpixel;
     modeinfo->maxlogicalwidth = 4088;
 	modeinfo->startaddressrange = apm_memory * 1024 - 1;
@@ -303,6 +306,10 @@ static void apm_initializemode(unsigned char *moderegs,
   moderegs[APMREG_SAVE(7)]= 1;          /* disable autoreset feature */
 
     k = comp_lmn(modetiming->pixelClock);
+    if (k==0){       
+       k = comp_lmn(modetiming->pixelClock*2);
+       if(k>0)moderegs[VGA_SR1] |= 8 ; /* Sequencer1 - clock halving */
+    };
     moderegs[APMREG_SAVE(14)]=k&0xff;
     moderegs[APMREG_SAVE(15)]=(k >> 8)&0xff;
     moderegs[APMREG_SAVE(16)]=(k >> 16)&0xff;
@@ -322,20 +329,6 @@ moderegs[2]=p&0xff;
 moderegs[APMREG_SAVE(4)]&=0xfd;
 moderegs[APMREG_SAVE(4)]|=(p&0x100)>>7;
 q=moderegs[4]+((moderegs[APMREG_SAVE(4)]&8)<<5); 
-/*switch(mode){
-case 10:
-r=p-q-24;
-break;
-case 11:
-r=p-q-55;
-break;
-case 12:
-r=p-q-21;
-break;
-case 39:
-r=p-q-2;
-break;
-}*/
 r=moderegs[0]+4;
 moderegs[3]&=0xe0;
 moderegs[3]|=(r&0x1f);
@@ -350,27 +343,12 @@ moderegs[0x9]&=0xdf;
 moderegs[0x9]|=(p&0x200)>>4;
 moderegs[APMREG_SAVE(3)]&=0xfb;
 moderegs[APMREG_SAVE(3)]|=(p&0x400)>>7;
-/*switch(mode){
-case 10:
-moderegs[0x16]+=43;
-break;
-case 11:
-moderegs[0x16]+=31;
-break;
-case 12:
-moderegs[0x16]+=25;
-break;
-case 39:
-moderegs[0x16]+=28;
-break;
-}*/
 moderegs[0x16]=moderegs[6]+1;
 }
     moderegs[APMREG_SAVE(10)] = 0xe8;  
     moderegs[APMREG_SAVE(11)] = 0x01;  
     moderegs[APMREG_SAVE(12)] = 0x1f;   
     moderegs[APMREG_SAVE(13)] = 0x07;  
-/*    new->XRE8 = RDXL_IOP(0xe8); */
 
 
 apm_is_linear=0;
@@ -645,7 +623,7 @@ static int apm_init(int force, int par1, int par2)
     cardspecs->maxPixelClock16bpp = 144000;	
     cardspecs->maxPixelClock24bpp = 75000;
     cardspecs->maxPixelClock32bpp = 94500;
-    cardspecs->flags = (CLOCK_PROGRAMMABLE | INTERLACE_DIVIDE_VERT | GREATER_1024_DIVIDE_VERT);
+    cardspecs->flags = CLOCK_PROGRAMMABLE | INTERLACE_DIVIDE_VERT;
     cardspecs->maxHorizontalCrtc = 2040;
     cardspecs->maxPixelClock4bpp = 0;
     cardspecs->nClocks =0;
@@ -699,10 +677,12 @@ comp_lmn(unsigned clock)
           if (f > 7) f = 7;
           if (f < 0) f = 0;
         }
+/*printf("clock=%i l=%i f=%i m=%i n=%i\n",clock,l,f,m,n);*/
         return (n << 16) | (m << 8) | (l << 2) | (f << 4);
       }
     }
   }
+/*printf("Can't do clock=%i\n",clock);*/
   return 0;
 }
 
