@@ -338,5 +338,6 @@ DriverSpecs __svgalib_ati_driverspecs =
     0,				/* extset */
     0,
     0,				/* linear */
-    NULL			/* accelspecs */
+    NULL,                       /* Accelspecs */
+    NULL,                       /* Emulation */
 };
