@@ -235,7 +235,8 @@ DriverSpecs __svgalib_ega_driverspecs =
     0,				/* extset */
     0,
     0,				/* linear */
-    NULL			/* accelspecs */
+    NULL,                       /* Accelspecs */
+    NULL,                       /* Emulation */
 };
 
 /* Initialize chipset (called after detection) */
