@@ -1,5 +1,5 @@
-                       /*  ET6000 driver  Don Secrest  version 0.22 */
-                       /*   March 24, 1998 */
+                       /*  ET6000 driver  Don Secrest  version 0.24 */
+                       /*   August 2, 1998 */
 #include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -36,14 +36,19 @@ static unsigned char *vgatextstore = 0;
 static unsigned long pci_confgspace = 0;
 static unsigned long base1;
 
-/* The following are set by init so that they may be restored to their */
-/* state in setmode.                                                   */
+/* The following are set by init so that they may be restored to their  */
+/* state in setmode.                                                    */
+static unsigned char pci13std,pci40std,pci42std,pci58std,pci59std=0;
+
+#define LMODEMIN 9   /* No mode below this has been tested for linear    */
+#define LMODEMAX 11  /* No mode above this tested.  These should change. */
+static unsigned char *et6000_frame_ptr = -1;  /* Mem pointer for linear. */
 
-static unsigned char pci40std,pci42std,pci58std,pci59std=0;
 static char mem_type;
 static int et6000_memory;
 static int et6000_chiptype;
 static int et6000_interlaced(int mode);
+static int et6000_setlinear(int addr);
 static et6000_chiptype = 0;
 static int x3_4,x3_5,x3_8 = 0,x3_a; /* On init these get set according */
 				    /*  to color */
@@ -210,10 +215,7 @@ static void et6000_setregs(const unsigned char regs[], int mode)
 {
   int i;
   unsigned char save;
-  /* et6000.setlinear(0);   Write this one! */
-  /* ET4000 shuts off linear at this point. */
-  /* We either do not have these registers  */
-  /* or they are read only.                 */
+  et6000_linear(LINEAR_DISABLE,0);  /* Turn off linear. */
 #ifdef DB6K
   fprintf(outf,"In setregs for regs at %x, mode = %d\n",(int) regs,mode);
   fflush(outf);
@@ -336,8 +338,8 @@ static int  et6000_init(int force, int par1, int par2)
     }
 #endif
   /* Check for ET6000 chiptype.                                             */
-  /* Get PCI and VL configuration space.  The VL buss has not been checked. */
-  /* I have a PCI buss.                                                     */
+  /* Get PCI and VL configuration space.  The VL bus has not been checked. */
+  /* I have a PCI bus.                                                     */
   if(!x3_8) {
     /* Test color mode or mono mode */
     if(inb(0x3cc) & 1) {
@@ -369,10 +371,10 @@ static int  et6000_init(int force, int par1, int par2)
     pci1 = inb(0xCF8);
     pci2 = inb(0xCFA);
                              /* It appears that the byte activation of 0xCF8
-			     ** is for a typ 2 PCI buss or perhaps a VESA buss,
-                             ** I dont know.  My buss is type 1 so I didn't do
+			     ** is for a typ 2 PCI bus or perhaps a VESA bus,
+                             ** I dont know.  My bus is type 1 so I didn't do
                              ** anything but test it.  I get back 0xFF, so then
-                             ** I try the long iout which works for my buss.
+                             ** I try the long iout which works for my bus.
                              */
 #ifdef DB6K
 fprintf(outf,"0xCF8 gives %d and 0xCFA gives %d\n",pci1,pci2);
@@ -406,7 +408,7 @@ fprintf(outf,"0xCF8 long gives %x, the old value was %x\n",(int) pcil2,
                          ** form is
 			 **        10000000000000nncccccfffoooooooo
                          ** where
-                         ** nn is the PCI buss number. I assumed only 1 nn = 0
+                         ** nn is the PCI bus number. I assumed only 1 nn = 0
 			 ** ccccc is the card number.  Mine is 0x14.
 			 ** fff is the function.  Mine is 0 and I assume it is
 			 ** true for video cards. It may not be, I don't know.
@@ -446,7 +448,8 @@ DPRT("Found et6000\n");
 			      ** of MDRAM.
 			      */
 		if(!pci59std) {
-		  /* Saving pcibuss registers so they may be restored. */
+		  /* Saving pcibus registers so they may be restored. */
+		  pci13std = inb(base1 | 0x13);
 		  pci40std = inb(base1 | 0x40);
 		  pci42std = inb(base1 | 0x42);
 		  pci58std = inb(base1 | 0x58);
@@ -469,8 +472,18 @@ DPRT("Found et6000\n");
 		    else
 		      et6000_memory = 1;      /* 1 MByte or DRAM  */
 		  }
-
+	/* Mmap for the frame pointer for linear. */
+		et6000_frame_ptr = (unsigned char *) mmap(
+							  (caddr_t) 0,
+						    et6000_memory*1024*1024,
+						    PROT_READ | PROT_WRITE,
+							  MAP_SHARED,
+							  __svgalib_mem_fd,
+							  0x10000000
+							  );
 #ifdef DB6K
+		fprintf(outf,"Et6k_frame_ptr = %x to %x\n",et6000_frame_ptr,
+			et6000_frame_ptr + et6000_memory*1024*1024);
 fprintf(outf,"pci_confgspace %08x, memtype %d and memsize %d MBytes\n",
        (int) pci_confgspace,mem_type,et6000_memory);
 #endif
@@ -538,10 +551,11 @@ DPRT("STDVGADRV\n");
 	i = inb(__svgalib_CRT_D);               /* 3#5 */
 	if ((i & 0x02) == 0x02)                 /* Clock0 select bit 2 */
 	    outb(__svgalib_CRT_D, (i & 0xFD));  /* Turn it off. */
-	                              /* Make sure pci buss is set right. */
+	                              /* Make sure pci bus is set right. */
 #ifdef DB6K
 	fprintf(outf,"reg 42 = %2x before.\n",inb(base1 | 0x42));
 #endif
+	outb(base1 | 0x13,pci13std);
 	outb(base1 | 0x40,pci40std);
 	outb(base1 | 0x42,pci42std);
 	outb(base1 | 0x58,pci58std);
@@ -589,14 +603,23 @@ static int  et6000_modeavailable(int mode)
 
 static void et6000_setdisplaystart(int address)
 {
-  DNOTW("setdisplaystart");
-  exit(1);
+  DPRT("setdisplaystart");
+  outw(x3_4, 0x0d + ((address ) & 0x00ff)*256);      /* ds0-7  */
+  outw(x3_4, 0x0c + ((address ) & 0xff00)*256);      /* ds0 15 */
+  /* inb(x3_a);                This was from the et4000 card /? ATC write 
+     outb(0x3c0,0x13 + 0x20);                                      mode.   
+  outb(0x3c0,(inb(0x3c1) & 0xf0) | ((address & 3) << 1));  ds0-1  */
+  outb(x3_4, 0x33);
+  outb(x3_5, (inb(x3_5) & 0xfc)  | ((address & 0xf0000) >> 16 ));
+                                                          /* ds 16-19 */
 }
 
 static void et6000_setlogicalwidth(int width)
 {
-  DNOTW("setlogicalwidth");
-  exit(1);
+  DPRT("setlogicalwidth");
+  outw(x3_4,0x13 + (((width >> 3 ) & 0xff) << 8));       /* lw3-10 */
+  outb(x3_4 ,0x3f);
+  outb(x3_5,(inb(x3_5) & 0x3f) | ((width & 0x1800) >> 3)); /* lw11-12 */
 }
 
 static void et6000_getmodeinfo(int mode,vga_modeinfo *modeinfo)
@@ -614,7 +637,7 @@ static void et6000_getmodeinfo(int mode,vga_modeinfo *modeinfo)
     break;
   }
   modeinfo->maxlogicalwidth = 4088;              /* Why? */
-  modeinfo->startaddressrange = 0xfffff;
+  modeinfo->startaddressrange = 0xfffff;  /* Mask for the startaddress */
   if(mode == G320x200x256)
     modeinfo->startaddressrange = 0;
   modeinfo->haveblit = 0;
@@ -622,8 +645,15 @@ static void et6000_getmodeinfo(int mode,vga_modeinfo *modeinfo)
   modeinfo->flags |= HAVE_RWPAGE | HAVE_EXT_SET;
   if(et6000_interlaced(mode))
     modeinfo->flags |= IS_INTERLACED;
-  modeinfo->flags |= EXT_INFO_AVAILABLE | CAPABLE_LINEAR;
-  modeinfo->chiptype = et6000_chiptype;
+  modeinfo->flags |= EXT_INFO_AVAILABLE;
+    if((mode > LMODEMIN) && (mode < LMODEMAX)) {
+      modeinfo->flags |= __svgalib_modeinfo_linearset | CAPABLE_LINEAR; 
+      modeinfo->linear_aperture = et6000_frame_ptr;
+    }
+    else modeinfo->linear_aperture = 0;
+  modeinfo->chiptype = et6000_chiptype;            /* is set in vgamisc.c  */
+  modeinfo->linewidth_unit = 8;
+  modeinfo->aperture_size = et6000_memory*1024;
 #ifdef DB6K
   fprintf(outf,"\nModeinfo at the end of the subroutine:\n");
   prtmodeinfo(modeinfo);
@@ -636,12 +666,12 @@ static void prtmodeinfo(vga_modeinfo *m)
 \ncolors\t\t\t%4d\nlinewidth\t\t%4d\nmaxlogicalwidth\t\t%4d\
 \nstartaddressrange\t%4d\nmaxpixels\t\t%4d\nhaveblit\t\t%4d\nflags\t\t\t%4x\
 \nchiptype\t\t%4d\nmemory\t\t\t%4dkbytes\nlinewidth_unit\t\t%4d\
-\nlinear_aperture\t\t%4s\naperture_size\t\t%4d\nset_aperture_page\t%4x\
+\nlinear_aperture\t\t%4x\naperture_size\t\t%4d\nset_aperture_page\t%4x\
 \nextensions\t\t%4s\n",
 	  m->width,m->height,m->bytesperpixel,m->colors,m->linewidth,
 	  m->maxlogicalwidth,m->startaddressrange,m->maxpixels,m->haveblit,
 	  m->flags,m->chiptype,m->memory,m->linewidth_unit,
-	  m->linear_aperture?"yes":"no",m->aperture_size,
+	  m->linear_aperture,m->aperture_size,
 	  m->set_aperture_page ? (int) *m->set_aperture_page : (int) 0,
 	  (int) m->extensions ? "yes" : "no");
 }
@@ -696,8 +726,41 @@ static int  et6000_accel(unsigned operation, va_list params)
 
 static int  et6000_linear(int op, int param)
 {
-  DNOTW("linear");
-  return(-1);
+#ifdef DB6K
+  fprintf(outf,"linear op = %d, param = %ld.\n",op,param);
+#endif
+  if(op == LINEAR_QUERY_BASE)
+    if((vga_getmodeinfo(vga_getcurrentmode())->flags | CAPABLE_LINEAR) &&
+       (et6000_frame_ptr != (char *) -1))
+      return((int) et6000_frame_ptr);
+    else                           /* frame_ptr is determined at init time */
+      return(-1);
+  else if(op == LINEAR_ENABLE)
+    {
+      et6000_setlinear(0x10);  /* This works but I may put in a loop to find */
+      port_out(0,SEG_SELECT);  /* one incase this doesn't work for everyone. */
+      port_out(0,0x3cb);
+      port_out(5,0x3ce);
+      port_out(0x40,0x3cf);  /* Set linear graphics. Don't touch this */
+                             /* on disable. */
+      outb(base1 | 0x40, 0x09);
+      /* Set memory relocation and linear. */
+    }
+  else if(op == LINEAR_DISABLE)
+    {
+      outb(base1 | 0x40, 0);
+      /* Turn off memory relocation and linear. */
+      et6000_setlinear(0);
+      __svgalib_modeinfo_linearset = 0;  /* In vga.c */
+      /*      port_out(5,0x3ce);
+      port_out(0x00,0x3cf); */
+    }
+  else if(op == LINEAR_QUERY_RANGE)
+    return(0);
+  else if(op == LINEAR_QUERY_GRANULARITY)
+    return(et6000_memory*1024*1024);
+  else return(-1);
+  return(0);
 }
 
 /* Programs not exported. */
@@ -719,3 +782,13 @@ static int et6000_interlaced(int mode)
 
                       /* This is a copy from et4000. */
 }
+
+static int et6000_setlinear(int addr)
+{
+  et6000_unlock();
+  if(addr)
+    outb(base1 | 0x13,addr);
+  else
+    outb(base1 | 0x13,pci13std);
+  return(0);
+}
