@@ -162,6 +162,7 @@ extern int __svgalib_kbd_fd;
 extern int __svgalib_runinbackground;
 
 extern unsigned char __svgalib_novga;
+extern unsigned char __svgalib_textprog;
 extern unsigned char __svgalib_secondary;
 extern unsigned char __svgalib_m_ignore_dx;
 extern unsigned char __svgalib_m_ignore_dy;
@@ -186,7 +187,9 @@ extern void __svgalib_flipaway(void);
 extern void (*__svgalib_mouse_eventhandler) (int, int, int, int, int, int, int);
 extern void (*__svgalib_keyboard_eventhandler) (int, int);
 extern void __joystick_flip_vc(int acquire);
-
+extern char *__svgalib_TextProg_argv[16]; /* should be enough */
+extern char *__svgalib_TextProg;
+extern unsigned char __svgalib_vesatext;
 
 #if 0 
 /* remove this part ? */
