@@ -444,6 +444,13 @@ static int ms_init(void)
     printf("m_accel_maxdelta: %ld\n",	(long)m_accel_maxdelta);
 #endif
 
+    /*  Ensure that the open will get a file descriptor greater
+     *  than 2, else problems can occur with stdio functions
+     *  under certain strange conditions:  */
+    if (fcntl(0,F_GETFD) < 0) open("/dev/null", O_RDONLY);
+    if (fcntl(1,F_GETFD) < 0) open("/dev/null", O_WRONLY);
+    if (fcntl(2,F_GETFD) < 0) open("/dev/null", O_WRONLY);
+
     /* Added O_NDELAY here. */
     if ((__svgalib_mouse_fd = open(m_dev, O_RDWR | O_NDELAY )) < 0)
 	return -1;
