@@ -83,17 +83,20 @@ return nv3_is_linear;
 
 static void nv3_getmodeinfo(int mode, vga_modeinfo *modeinfo)
 {
-	modeinfo->maxpixels = nv3_memory*1024/modeinfo->bytesperpixel;
-    modeinfo->maxlogicalwidth = 4088;
-	modeinfo->startaddressrange = nv3_memory * 1024 - 1;
-	modeinfo->haveblit = 0;
-    modeinfo->flags &= ~HAVE_RWPAGE;
+   
+   if(modeinfo->colors==16)return;
+   
+   modeinfo->maxpixels = nv3_memory*1024/modeinfo->bytesperpixel;
+   modeinfo->maxlogicalwidth = 4088;
+   modeinfo->startaddressrange = nv3_memory * 1024 - 1;
+   modeinfo->haveblit = 0;
+   modeinfo->flags &= ~HAVE_RWPAGE;
 
-    if (modeinfo->bytesperpixel >= 1) {
+   if (modeinfo->bytesperpixel >= 1) {
 	modeinfo->flags |= CAPABLE_LINEAR;
         if (__svgalib_nv3_inlinearmode())
 	    modeinfo->flags |= IS_LINEAR;
-    }
+   }
 }
 
 /* Read and save chipset-specific registers */
@@ -421,9 +424,20 @@ __svgalib_outSR(LOCK_EXT_INDEX,UNLOCK_EXT_MAGIC+1);
 /* Indentify chipset, initialize and return non-zero if detected */
 
 static int nv3_test(void)
-{  unsigned long buf[16];
-   
-   if (__svgalib_pci_find_vendor_vga(0x12d2,buf))return 0;
+{  unsigned long buf[64];
+   int found=0;
+   int _ioperm=0;
+
+   if (getenv("IOPERM") == NULL) {
+     _ioperm=1;
+     if (iopl(3) < 0) {
+       printf("svgalib: nv3: cannot get I/O permissions\n");
+       exit(1);
+     }
+   }
+   found=__svgalib_pci_find_vendor_vga(0x12d2,buf);
+   if (_ioperm) iopl(0);
+   if (found)return 0;
    if (((buf[0]>>16)&0xffff)!=0x18)return 0;
    MMIOBASE=buf[4]&0xffffff00;
    LINEARBASE=buf[5]&0xffffff00;
@@ -554,7 +568,7 @@ static int nv3_init(int force, int par1, int par2)
     cardspecs->maxPixelClock16bpp = 230000;	
     cardspecs->maxPixelClock24bpp = 230000;
     cardspecs->maxPixelClock32bpp = 230000;
-    cardspecs->flags = (CLOCK_PROGRAMMABLE | INTERLACE_DIVIDE_VERT | GREATER_1024_DIVIDE_VERT);
+    cardspecs->flags = CLOCK_PROGRAMMABLE ;
     cardspecs->maxHorizontalCrtc = 2040;
     cardspecs->maxPixelClock4bpp = 0;
     cardspecs->nClocks =0;
