@@ -765,7 +765,8 @@ DriverSpecs __svgalib_oak_driverspecs =
     0,				/* extset */
     0,
     0,				/* linear */
-    NULL,			/* accelspecs */
+    NULL,                       /* Accelspecs */
+    NULL,                       /* Emulation */
 #if 0
     (int (*)()) oak_setlinearmode,
     (int (*)()) oak_clearlinearmode,
