@@ -1350,7 +1350,8 @@ DriverSpecs __svgalib_s3_driverspecs =
     s3_ext_set,			/* extset */
     0,				/* accel */
     S3_LINEAR_FUNC,		/* linear */
-    NULL			/* accelspecs */
+    NULL,                       /* Accelspecs */
+    NULL,                       /* Emulation */
 };
 
 
@@ -1567,6 +1568,7 @@ static int s3_init(int force, int par1, int par2)
 	    case 0x10E0:
 		s3_chiptype = S3_TRIO32;
 		break;
+	    case 0x3DE0: /* ViRGE/VX ID */
 	    case 0x31E0: /* ViRGE ID */
 	    case 0x01E0: /* S3Trio64V2/DX ... any others? */
 	    case 0x11E0:
