@@ -157,6 +157,8 @@ struct info infotable[] =
 unsigned long __svgalib_graph_base = GRAPH_BASE;
 
 unsigned char __svgalib_novga = 0;     /* Does not have VGA circuitry on board */
+unsigned char __svgalib_vesatext = 0;
+unsigned char __svgalib_textprog = 0;  /* run a program when returning to text mode */
 unsigned char __svgalib_secondary = 0; /* this is not the main card with VC'S (not yet supported) */
 
 /* default palette values */
@@ -219,6 +221,9 @@ static const unsigned char default_blue[256]
 static unsigned char text_regs[MAX_REGS];	/* VGA registers for saved text mode */
 
 
+char *__svgalib_TextProg_argv[16]; /* should be enough */
+char *__svgalib_TextProg;
+
 /* saved text mode palette values */
 static unsigned char text_red[256];
 static unsigned char text_green[256];
@@ -444,7 +449,12 @@ DriverSpecs *__svgalib_driverspecslist[] =
     NULL,
 #endif
 #ifdef INCLUDE_VESA_DRIVER
-    &__svgalib_vesa_driverspecs
+    &__svgalib_vesa_driverspecs,
+#else
+    NULL,
+#endif
+#ifdef INCLUDE_VESA_DRIVER
+    &__svgalib_mx_driverspecs
 #else
     NULL
 #endif
@@ -453,7 +463,7 @@ DriverSpecs *__svgalib_driverspecslist[] =
 static char *driver_names[] =
 {"", "VGA", "ET4000", "Cirrus", "TVGA", "Oak", "EGA", "S3",
  "ET3000", "Mach32", "GVGA6400", "ARK", "ATI", "ALI", "Mach64", 
- "C&T", "APM", "NV3", "ET6000", "VESA", NULL};
+ "C&T", "APM", "NV3", "ET6000", "VESA", "MX", NULL};
 
 /* Chipset drivers */
 
@@ -565,6 +575,13 @@ static void open_mem(void)
  char tmp[40];
 #endif
 #endif
+    /*  Ensure that the open will get a file descriptor greater
+     *  than 2, else problems can occur with stdio functions
+     *  under certain strange conditions:  */
+    if (fcntl(0,F_GETFD) < 0) open("/dev/null", O_RDONLY);
+    if (fcntl(1,F_GETFD) < 0) open("/dev/null", O_WRONLY);
+    if (fcntl(2,F_GETFD) < 0) open("/dev/null", O_WRONLY);
+
     if (__svgalib_mem_fd < 0)
 	if ((__svgalib_mem_fd = open("/dev/mem", O_RDWR)) < 0) {
 	    printf("svgalib: Cannot open /dev/mem.\n");
@@ -618,6 +635,12 @@ void __svgalib_open_devconsole(void)
     if (__svgalib_tty_fd >= 0)
         return;
 
+    /*  The code below assumes file descriptors 0, 1, and 2
+     *  are already open; make sure that's true.  */
+    if (fcntl(0,F_GETFD) < 0) open("/dev/null", O_RDONLY);
+    if (fcntl(1,F_GETFD) < 0) open("/dev/null", O_WRONLY);
+    if (fcntl(2,F_GETFD) < 0) open("/dev/null", O_WRONLY);
+
     /*
      * Now, it would be great if we could use /dev/tty and see what it is connected to.
      * Alas, we cannot find out reliably what VC /dev/tty is bound to. Thus we parse
@@ -921,6 +944,14 @@ static void restoretextmode(void)
             ioctl(__svgalib_tty_fd, VT_SETMODE, &__svgalib_oldvtmode);
 	}
     }
+    if((__svgalib_textprog&3)==3){
+       pid_t child;
+       if((child=fork())==0){
+       execv(__svgalib_TextProg,__svgalib_TextProg_argv);
+       } else {
+       waitpid(child,NULL,0);
+       };
+    };
 }
 
 static void idle_accel(void) {
@@ -1046,6 +1077,11 @@ int __svgalib_getchipset(void)
 	    CHIPSET = NV3;
 	else
 #endif
+#ifdef INCLUDE_MX_DRIVER_TEST
+	if (__svgalib_mx_driverspecs.test())
+	    CHIPSET = MX;
+	else
+#endif
 #ifdef INCLUDE_APM_DRIVER_TEST
 /* Note: On certain cards this may toggle the video signal on/off which
    is ugly. Hence we test this last. */
@@ -1191,6 +1227,14 @@ static void __svgalib_releasevt_signal(int n)
 	return;
     }
     __svgalib_flipaway();
+        if((__svgalib_textprog&3)==3){
+           pid_t child;
+           if((child=fork())==0){
+           execv(__svgalib_TextProg,__svgalib_TextProg_argv);
+           } else {
+           waitpid(child,NULL,0);
+           };  
+        };
     ioctl(__svgalib_tty_fd, VT_RELDISP, 1);
 #ifdef DEBUG
     printf("Finished release.\n");
@@ -1201,6 +1245,7 @@ static void __svgalib_releasevt_signal(int n)
 #ifdef DEBUG
     printf("Suspended.\n");
 #endif
+
     __svgalib_oktowrite = 0;
     if (!__svgalib_runinbackground)
 	__svgalib_waitvtactive();
@@ -1773,7 +1818,7 @@ int vga_setmode(int mode)
 	if (__svgalib_getchipset() == CHIPS) {
 	   while (((port_in(__svgalib_IS1_R)) & 0x08) == 0x08 );/* wait VSync off */
 	   while (((port_in(__svgalib_IS1_R)) & 0x08) == 0 );   /* wait VSync on  */
-	   port_outw(0x3C4,0x07);         /* reset hsync - just in case...  */
+	   port_outw(0x07,0x3C4);         /* reset hsync - just in case...  */
 	}
     }
 
@@ -1879,7 +1924,10 @@ int vga_setmode(int mode)
         if (!__svgalib_secondary)
 	    ioctl(__svgalib_tty_fd, KDSETMODE, KD_TEXT);
 
-	usleep(MODESWITCHDELAY);	/* wait for signal to stabilize */
+        /* now wait for signal to stabilize, but don't do it on C&T chips. */
+        /* This is needed to restore correct text mode stretching.         */
+	if (__svgalib_chipset != CHIPS)
+	    usleep(MODESWITCHDELAY);
 
 	/* enable video */
 	vga_screenon();
@@ -1914,7 +1962,6 @@ int vga_setmode(int mode)
 	CI.bytesperpixel = infotable[mode].bytesperpixel;
 
 	chipset_setmode(mode, prv_mode);
-
 	MODEX = 0;
 
 	/* Set default claimed memory (moved here from initialize - Michael.) */
@@ -2625,7 +2672,15 @@ void __svgalib_flipaway(void)
 	/* Save state and go to textmode. */
 	savestate();
 	flip = 1;
-	vga_setmode(TEXT);
+        if((__svgalib_textprog&3)==3){
+/*           pid_t child;
+           if((child=fork())==0){
+           execv(__svgalib_TextProg,__svgalib_TextProg_argv);
+           } else {
+           waitpid(child,NULL,0);
+           }; */
+        } else 
+        vga_setmode(TEXT);
 	flip = 0;
 
 #ifdef BACKGROUND
@@ -3014,6 +3069,7 @@ static char *vga_conf_commands[] = {
     "setrts", "grayscale", "horizsync", "vertrefresh", "modeline",
     "security","mdev", "default_mode", "nosigint", "sigint",
     "joystick0", "joystick1", "joystick2", "joystick3",
+    "TextProg", "VesaText",
     NULL};
 
 static char *conf_mousenames[] =
@@ -3387,9 +3443,7 @@ static char *process_option(int command, int mode)
 	if (ptr) {
 	    mouse_device = strdup(ptr);
 	    if (mouse_device == NULL) {
-#ifndef SVGA_AOUT
 	      nomem:
-#endif
 		puts("svgalib: Fatal error: out of memory.");
 		exit(1);
 	    }
@@ -3434,6 +3488,29 @@ static char *process_option(int command, int mode)
 	printf("svgalib: No joystick support in a.out version.\n");
 #endif
 	break;
+    case 55: /* TextProg */
+	ptr = strtok(NULL," ");
+        if(ptr==NULL)break;
+        __svgalib_textprog|=2;
+	__svgalib_TextProg = strdup(ptr);
+	if (!__svgalib_TextProg)
+	    goto nomem;
+        i=1;
+        while(((ptr=strtok(NULL," "))!=NULL) &&
+	       (i< ((sizeof(__svgalib_TextProg_argv) / sizeof(char *)) + 1)) &&
+	       strcmp(ptr,"END")){
+	   __svgalib_TextProg_argv[i]=strdup(ptr);
+	   if (!__svgalib_TextProg_argv[i])
+	       goto nomem;
+	   i++;
+        };
+        __svgalib_TextProg_argv[i]=NULL;
+        ptb=strrchr(__svgalib_TextProg,'/');
+        __svgalib_TextProg_argv[0]=ptb?ptb + 1:__svgalib_TextProg;
+        break;
+    case 56:
+        __svgalib_vesatext=1;
+        break;
     }
   leave:
     return strtok(NULL, " ");
