@@ -96,7 +96,12 @@ static unsigned char *
 #ifndef BACKGROUND
 
     unsigned char *fb;
-    mem_fd = open("/dev/mem", O_RDWR);
+
+    mem_fd = __svgalib_mem_fd;
+    if (mem_fd == -1) {
+	printf("svgalib: memory handle not initialized!\n");
+	exit(-1);
+    }
     fb = valloc(size);
     return mmap(
 		   (caddr_t) fb,
@@ -114,8 +119,12 @@ static unsigned char *
 #ifdef BACKGROUND
 #if BACKGROUND == 1
  /* Probably won't go right at first try. */
- 
-    mem_fd = open("/dev/mem", O_RDWR); 
+
+    mem_fd = __svgalib_mem_fd;
+    if (mem_fd == -1) {  /* sanity check */
+	printf("svgalib: memory handle not initialized!\n");
+	exit(-1);
+    }
     if ((__svgalib_linearframebuffer = valloc(size)) == NULL) {
 	printf("svgalib: allocation error \n");
 	exit(-1);
@@ -180,6 +189,7 @@ static int verify_one_linear_mapping(int base, int size)
 	}
     }
     /* Linear framebuffer is OK. */
+    if(__svgalib_driver_report)
     printf("svgalib: Found linear framebuffer at 0x%08X.\n", base);
     result = 0;
     munmap((caddr_t) fb, size);
@@ -214,7 +224,7 @@ int vga_setlinearaddressing(void)
     vga_modeinfo *modeinfo;
     modeinfo = vga_getmodeinfo(__svgalib_cur_mode);
     if (modeinfo->flags & EXT_INFO_AVAILABLE)
-	memory = modeinfo->memory;
+	memory = modeinfo->memory * 1024;
     else
 	memory = (modeinfo->bytesperpixel * modeinfo->maxpixels
 		  + 0xFFF) & 0xFFFFF000;	/* Round up 4K. */
