@@ -8,14 +8,14 @@
 #define PCI_CONF_DATA  0xcfc
 
 
-static int pci_read_header (unsigned char bus, unsigned char device,
+static int pci_read_config (unsigned char bus, unsigned char device,
         unsigned char fn, unsigned long *buf)
 {
   int i;
   unsigned long bx = ((fn&7)<<8) | ((device&31)<<11) | (bus<<16) |
                         0x80000000;
 
-  for (i=0; i<16; i++) {
+  for (i=0; i<64; i++) {
         outl (PCI_CONF_ADDR, bx|(i<<2));
         buf[i] = inl (PCI_CONF_DATA);
   }
@@ -27,30 +27,27 @@ static int pci_read_header (unsigned char bus, unsigned char device,
 /* find a vga device of the specified vendor, and return
    its configuration (16 dwords) in conf 
    return zero if device found.
-   */ 
+
+   Remark 1: It's the caller's responsibility to make sure that
+             the PCI ports are accessible. In practice, (under kernels
+             2.0.x, I don't know about 2.1.x) this means iopl(3).  
+
+*/ 
+
 int __svgalib_pci_find_vendor_vga(unsigned int vendor, unsigned long *conf)
-{ unsigned long buf[16];
+{ unsigned long buf[64];
   int bus,device,cont;
   
   cont=1;
 
-  if (getenv("IOPERM") == NULL) {
-        if (iopl(3) < 0) {
-	    printf("svgalib: vgapci: cannot get I/O permissions\n");
-	    exit(1);
-	}
-  }
-
   for(bus=0;(bus<16)&&cont;bus++)              
     for(device=0;(device<256)&&cont;device++){
-      pci_read_header(bus,device,0,buf);
-      if(((buf[0]&0xffff)==vendor)&&(((buf[2]>>16)&0xffff)==0x0300))cont=0;
+      pci_read_config(bus,device,0,buf);
+      if(((buf[0]&0xffff)==vendor)&&
+        (((buf[2]>>16)&0xffff)==0x0300))  /* VGA Class */
+          cont=0;
     };
-  if(!cont){memcpy(conf,buf,64); };
-/*  for(i=0;i<16;i++)printf("%u\n",buf[i]);*/
-
-  if (getenv("IOPERM") == NULL)
-  	iopl(0);
+  if(!cont){memcpy(conf,buf,256); };
 
   return cont;
 }
